<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Border;
/**
 *
 * Header Widget .
 *
 */
class Metize_Header extends Widget_Base {

	public function get_name() {
		return 'metizeheader';
	}

	public function get_title() {
		return __( 'Header', 'metize' );
	}

	public function get_icon() {
		return 'vt-icon';
    }

	public function get_categories() {
		return [ 'metize_header_elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'header_section',
			[
				'label' 	=> __( 'Header', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );
        $this->add_control(
			'header_style',
			[
				'label' 		=> __( 'Header Style', 'metize' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'metize' ),
					'2' 		=> __( 'Style Two', 'metize' ),
					'3' 		=> __( 'Style Three', 'metize' ),
					'4' 		=> __( 'Style Four', 'metize' ),
				],
			]
		);

		$this->add_control(
			'support_text',
			[
				'label' 	=> __( 'Support Text', 'metize' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'Have any Questions?', 'metize' ),
                'condition'		=> ['header_style' => '3' ],
			]
        );
        $this->add_control(
			'support_email',
			[
				'label' 	=> __( 'Support E-Mail', 'metize' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'info@digital.com', 'metize' ),
                'condition'		=> ['header_style' => '3' ],
			]
        );
        

		$this->add_control(
			'logo_image',
			[
				'label' 		=> __( 'Upload Logo Light Image', 'metize' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'logo_image_dark',
			[
				'label' 		=> __( 'Upload Logo Dark Image', 'metize' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition'		=> [ 'header_style' => '1'  ],
			]
		);
		$this->add_control(
			'logo_image_mobile',
			[
				'label' 		=> __( 'Upload Logo For Mobile Device', 'metize' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition'		=> [ 'header_style' => '1'  ],
			]
		);
        
		
		$this->add_control(
			'button_text',
			[
				'label' 	=> __( 'Button Text 1', 'metize' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'default'  	=> __( 'Button Text', 'metize' ),
                'rows' 		=> 2,
                'condition'		=> [ 'header_style' => ['1','2']  ],
			]
        );

        $this->add_control(
			'button_link',
			[
				'label' 		=> __( 'Link 1', 'metize' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'metize' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition'		=> [ 'header_style' => ['1','2']  ],
			]
		);

		

		$menus = $this->metize_menu_select();

		if( !empty( $menus ) ){
	        $this->add_control(
				'metize_menu_select',
				[
					'label'     	=> __( 'Select Metize Menu', 'metize' ),
					'type'      	=> Controls_Manager::SELECT,
					'options'   	=> $menus,
					'description' 	=> sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'metize' ), admin_url( 'nav-menus.php' ) ),
					'condition'		=> [ 'header_style' => [ '1','2', '3'] ],
				]
			);
		}else {
			$this->add_control(
				'no_menu',
				[
					'type' 				=> Controls_Manager::RAW_HTML,
					'raw' 				=> '<strong>' . __( 'There are no menus in your site.', 'metize' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'metize' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'separator' 		=> 'after',
					'content_classes' 	=> 'elementor-panel-alert elementor-panel-alert-info',
					'condition'		=> [ 'header_style' => [ '1','2', '3'] ],
				]
			);
		}

        $this->end_controls_section();

		//---------------------------------------MenuBar Style---------------------------------------//

		$this->start_controls_section(
			'menubar_style_section',
			[
				'label' 	=> __( 'MenuBar Style', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );
        $this->add_control(
			'menubar_color',
			[
				'label' 		=> __( 'Menubar Background Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} nav.navbar.validnavs.no-background' => 'background-color: {{VALUE}}!important;',
                ],
			]
        );
        $this->add_control(
			'sticky_menubar_color',
			[
				'label' 		=> __( 'Sticky Menubar Background Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} nav.navbar.validnavs' => 'background-color: {{VALUE}}!important;',
                ],
			]
        );
         $this->add_control(
			'search_icon_color',
			[
				'label' 		=> __( 'Icon Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} nav.navbar.validnavs.no-background.white .attr-nav > ul > li > a' => '--white: {{VALUE}}!important;',
                ],
			]
        );
        $this->end_controls_section();

        //---------------------------------------Menu Style---------------------------------------//


		$this->start_controls_section(
			'section_con_styling',
			[
				'label' 	=> __( 'Menu Control', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );
        $this->start_controls_tabs(
			'style_tabs3'
		);


		$this->start_controls_tab(
			'style_normal_tab3',
			[
				'label' => esc_html__( 'Menu', 'metize' ),
			]
		);
         $this->add_control(
			'menu_color',
			[
				'label' 		=> __( 'Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .no-background ul.nav > li > a' => '--white: {{VALUE}}!important;',
                ],
			]
        );
        $this->add_control(
			'menu_hvr_color',
			[
				'label' 		=> __( 'Hover Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .no-background ul.nav > li > a:hover' => 'color: {{VALUE}}!important;',
                ],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 's_title_typography',
		 		'label' 		=> __( 'Typography', 'metize' ),
		 		'selector' 	=> '{{WRAPPER}} nav.navbar ul.nav > li > a',
			]
		);

        
		$this->end_controls_tab();

		//--------------------secound--------------------//

		$this->start_controls_tab(
			'submenu_normal_tab3',
			[
				'label' => esc_html__( 'Submenu', 'metize' ),
			]
		);
         $this->add_control(
			'submenu_menu_color',
			[
				'label' 		=> __( 'Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} nav.navbar.validnavs ul li.dropdown ul.dropdown-menu li a' => 'color: {{VALUE}}',
                ],
			]
        );
        $this->add_control(
			'submenu_menu_hvr_color',
			[
				'label' 		=> __( 'Hover Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} nav.navbar.validnavs ul li.dropdown ul.dropdown-menu li a:hover' => 'color: {{VALUE}}!important;',
                ],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 'submenu_title_typography',
		 		'label' 		=> __( 'Typography', 'metize' ),
		 		'selector' 	=> '{{WRAPPER}} nav.navbar.validnavs ul li.dropdown ul.dropdown-menu li a',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();
    }

    public function metize_menu_select(){
	    $metize_menu = wp_get_nav_menus();
	    $menu_array  = array();
		$menu_array[''] = __( 'Select A Menu', 'metize' );
	    foreach( $metize_menu as $menu ){
	        $menu_array[ $menu->slug ] = $menu->name;
	    }
	    return $menu_array;
	}

	protected function render() {

        $settings = $this->get_settings_for_display();
        $metize_avaiable_menu   = $this->metize_menu_select();

		if( ! $metize_avaiable_menu ){
			return;
		}

		$args = [
			'menu'  => $settings['metize_menu_select'],
            'container'       => 'ul',
            'menu_class'      => 'nav navbar-nav navbar-center',
            'fallback_cb'     => 'Metize_Bootstrap_Navwalker::fallback',
            'items_wrap'      => '<ul data-in="fadeInDown" data-out="fadeOutUp" class="%2$s" id="%1$s">%3$s</ul>',
            'walker'          => new Metize_Bootstrap_Navwalker(),
		];

        if($settings['header_style'] == 1) {


        	echo '<nav class="navbar mobile-sidenav navbar-sticky navbar-default validnavs navbar-fixed white no-background">';

	            echo '<div class="container d-flex justify-content-between align-items-center">            ';
	                

	                echo '<!-- Start Header Navigation -->';
	                echo '<div class="navbar-header">';
	                    echo '<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-menu"><i class="fa fa-bars"></i></button>';
	                    if( ! empty( $settings['logo_image']['url'] ) ){
		                    echo '<a class="navbar-brand" href="'.esc_url( home_url( '/' ) ).'">';
		                        echo metize_img_tag( array(
									'url'	=> esc_url( $settings['logo_image']['url'] ),
									'class' => 'logo logo-display'
								) );
								if( ! empty( $settings['logo_image_dark']['url'] ) ){
									echo metize_img_tag( array(
										'url'	=> esc_url( $settings['logo_image_dark']['url'] ),
										'class' => 'logo logo-scrolled'
									) );
								}
		                    echo '</a>';
		                }
	                echo '</div>';
	                echo '<!-- End Header Navigation -->';

	                echo '<!-- Collect the nav links, forms, and other content for toggling -->';
	                echo '<div class="collapse navbar-collapse" id="navbar-menu">';

	                    if( ! empty( $settings['logo_image_mobile']['url'] ) ){
		                    echo metize_img_tag( array(
								'url'	=> esc_url( $settings['logo_image_mobile']['url'] ),
							) );
		                }
	                    echo '<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-menu"><i class="fa fa-times"></i></button>';
	                    
	                    if( ! empty( $settings['metize_menu_select'] ) ){
							wp_nav_menu( $args );
						}
	                    

	                    
	                echo '</div><!-- /.navbar-collapse -->';

	                echo '<div class="attr-right">';
	                    echo '<!-- Start Atribute Navigation -->';
	                    echo '<div class="attr-nav">';
	                        
                        	if( ! empty( $settings['button_text'] ) ) {
                        		if( ! empty( $settings['button_link']['url'] ) ) {
						            $this->add_render_attribute( 'button', 'href', esc_url( $settings['button_link']['url'] ) );
						        }

						        if( ! empty( $settings['button_link']['nofollow'] ) ) {
						            $this->add_render_attribute( 'button', 'rel', 'nofollow' );
						        }

						        if( ! empty( $settings['button_link']['is_external'] ) ) {
						            $this->add_render_attribute( 'button', 'target', '_blank' );
						        }
						        echo '<ul>';
						        	echo '<li class="button">';
                                		echo '<a '.$this->get_render_attribute_string('button').'>'.esc_html( $settings['button_text'] ).'</a>';
                                	echo '</li>';
                                echo '</ul>';
                            }
	                    echo '</div>';
	                    echo '<!-- End Atribute Navigation -->';

	                    echo '<!-- Overlay screen for menu -->';
	                    echo '<div class="overlay-screen"></div>';
	                    echo '<!-- End Overlay screen for menu -->';

	                echo '</div>';
	                echo '<!-- Main Nav -->';

	            echo '</div>   ';
	        echo '</nav>';
	    }elseif($settings['header_style'] == 2) {

	    	echo '<nav class="navbar mobile-sidenav navbar-sticky navbar-default validnavs navbar-fixed dark no-background">';

	            echo '<div class="container d-flex justify-content-between align-items-center">            ';
	                

	                echo '<!-- Start Header Navigation -->';
	                echo '<div class="navbar-header">';
	                    echo '<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-menu"><i class="fa fa-bars"></i></button>';
	                    if( ! empty( $settings['logo_image']['url'] ) ){
		                    echo '<a class="navbar-brand" href="'.esc_url( home_url( '/' ) ).'">';
		                        echo metize_img_tag( array(
									'url'	=> esc_url( $settings['logo_image']['url'] ),
								) );
								
		                    echo '</a>';
		                }
	                echo '</div>';
	                echo '<!-- End Header Navigation -->';

	                echo '<!-- Collect the nav links, forms, and other content for toggling -->';
	                echo '<div class="collapse navbar-collapse" id="navbar-menu">';

	                    echo metize_img_tag( array(
							'url'	=> esc_url( $settings['logo_image']['url'] ),
						) );
	                    echo '<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-menu"><i class="fa fa-times"></i></button>';
	                    
	                    if( ! empty( $settings['metize_menu_select'] ) ){
							wp_nav_menu( $args );
						}
	                    

	                    
	                echo '</div><!-- /.navbar-collapse -->';

	                echo '<div class="attr-right">';
	                    echo '<!-- Start Atribute Navigation -->';
	                    echo '<div class="attr-nav">';
	                        
                        	if( ! empty( $settings['button_text'] ) ) {
                        		if( ! empty( $settings['button_link']['url'] ) ) {
						            $this->add_render_attribute( 'button', 'href', esc_url( $settings['button_link']['url'] ) );
						        }

						        if( ! empty( $settings['button_link']['nofollow'] ) ) {
						            $this->add_render_attribute( 'button', 'rel', 'nofollow' );
						        }

						        if( ! empty( $settings['button_link']['is_external'] ) ) {
						            $this->add_render_attribute( 'button', 'target', '_blank' );
						        }
						        echo '<ul>';
						        	echo '<li class="button">';
                                		echo '<a '.$this->get_render_attribute_string('button').'>'.esc_html( $settings['button_text'] ).'</a>';
                                	echo '</li>';
                                echo '</ul>';
                            }
	                    echo '</div>';
	                    echo '<!-- End Atribute Navigation -->';

	                    echo '<!-- Overlay screen for menu -->';
	                    echo '<div class="overlay-screen"></div>';
	                    echo '<!-- End Overlay screen for menu -->';

	                echo '</div>';
	                echo '<!-- Main Nav -->';

	            echo '</div>   ';
	        echo '</nav>';
	    }else{

	    	echo '<nav class="navbar mobile-sidenav navbar-sticky navbar-default validnavs navbar-fixed dark no-background">';

	            echo '<div class="container d-flex justify-content-between align-items-center">            ';
	                

	                echo '<!-- Start Header Navigation -->';
	                echo '<div class="navbar-header">';
	                    echo '<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-menu"><i class="fa fa-bars"></i></button>';
	                    if( ! empty( $settings['logo_image']['url'] ) ){
		                    echo '<a class="navbar-brand" href="'.esc_url( home_url( '/' ) ).'">';
		                        echo metize_img_tag( array(
									'url'	=> esc_url( $settings['logo_image']['url'] ),
								) );
								
		                    echo '</a>';
		                }
	                echo '</div>';
	                echo '<!-- End Header Navigation -->';

	                echo '<!-- Collect the nav links, forms, and other content for toggling -->';
	                echo '<div class="collapse navbar-collapse" id="navbar-menu">';

	                    echo metize_img_tag( array(
							'url'	=> esc_url( $settings['logo_image']['url'] ),
						) );
	                    echo '<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-menu"><i class="fa fa-times"></i></button>';
	                    
	                    if( ! empty( $settings['metize_menu_select'] ) ){
							wp_nav_menu( $args );
						}
	                    

	                    
	                echo '</div><!-- /.navbar-collapse -->';
	                if(!empty($settings['support_text'])){
		                echo '<div class="attr-right">';
		                    echo '<!-- Start Atribute Navigation -->';
		                    echo '<div class="attr-nav">';
		                        
	                        	echo '<ul>';
		                            echo '<li class="contact">';
		                                echo '<div class="call">';
		                                    echo '<div class="icon"><i class="fas fa-comments-alt-dollar"></i></div>';
		                                    echo '<div class="info">';
		                                        echo '<p>'.esc_html($settings['support_text']).'</p>';
		                                        if(!empty($settings['support_email'])){
			                                        echo '<h5><a href="mailto:'.esc_attr($settings['support_text']).'">'.esc_html($settings['support_email']).'</a></h5>';
			                                    }
		                                    echo '</div>';
		                                echo '</div>';
		                            echo '</li>';
		                        echo '</ul>';
		                    echo '</div>';
		                    echo '<!-- End Atribute Navigation -->';

		                    echo '<!-- Overlay screen for menu -->';
		                    echo '<div class="overlay-screen"></div>';
		                    echo '<!-- End Overlay screen for menu -->';

		                echo '</div>';
		                echo '<!-- Main Nav -->';
		            }
	            echo '</div>';
	        echo '</nav>';
	    }
	}

}