<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * process Widget .
 *
 */
class Metize_Features extends Widget_Base {

	public function get_name() {
		return 'metizefeatures';
	}

	public function get_title() {
		return __( 'Metize Features', 'metize' );
	}


	public function get_icon() {
		return 'vt-icon';
    }


	public function get_categories() {
		return [ 'metize' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'work_process_section',
			[
				'label' 	=> __( 'Features', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );
        $this->add_control(
			'layout',
			[
				'label' 		=> __( 'Style', 'metize' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options'		=> [
					'1'  			=> __( 'Style One', 'metize' ),
					'2' 			=> __( 'Style Two', 'metize' ),
					'3' 			=> __( 'Style Three', 'metize' ),
					'4' 			=> __( 'Style Four', 'metize' ),
					'5' 			=> __( 'Style Five', 'metize' ),
				],
			]
		);
		$this->add_control(
			'bg',
			[
				'label' 		=> __( 'Background', 'metize' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 			=> Utils::get_placeholder_image_src(),
				],
				'condition'		=> [ 'layout' => ['1','3','4'] ],
			]
		);

		$this->add_control(
			'title',
			[
				'label'     	=> __( 'Title', 'metize' ),
                'type'      	=> Controls_Manager::TEXTAREA,
                'rows' 			=> 2,
                'default' 		=>  __( 'This is title area', 'metize'),
                'condition'		=> [ 'layout' => ['1','3'] ],
			]
        );
        $this->add_control(
			'subtitle',
			[
				'label'     	=> __( 'Subtitle', 'metize' ),
                'type'      	=> Controls_Manager::TEXTAREA,
                'rows' 			=> 2,
                'default' 		=>  __( 'This is subtitle area', 'metize'),
                'condition'		=> [ 'layout' => ['1','3'] ],
			]
        );
        $this->add_control(
			'desc',
			[
				'label'     	=> __( 'Description', 'metize' ),
                'type'      	=> Controls_Manager::WYSIWYG,
                'default' 		=>  __( 'This is subtitle area', 'metize'),
                'condition'		=> [ 'layout' => ['1'] ],
			]
        );
        
 
		$repeater1 = new Repeater();

		
		$repeater1->add_control(
			'process_title',
			[
				'label'     => __( 'Title', 'metize' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default' 		=> __( 'Project Planning' , 'metize' ),
			]
        );
        $repeater1->add_control(
			'process_con',
			[
				'label'     => __( 'Content', 'metize' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default' 		=> __( 'Customize templates and create unique campaigns ' , 'metize' ),
			]
        );
        $repeater1->add_control(
			'img_or_icon',
			[
				'label' 		=> __( 'Image or icon', 'metize' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options'		=> [
					'1'  			=> __( 'Icon Class', 'metize' ),
					'2' 			=> __( 'image', 'metize' ),
					// '3' 			=> __( 'Style Three', 'metize' ),
					// '1' 			=> __( 'Style Four', 'metize' ),
				],
			]
		);
        $repeater1->add_control(
			'icon',
			[
				'label'     => __( 'Icon Class', 'metize' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'condition'		=> [ 'img_or_icon' => [ '1']  ],
			]
        );
        $repeater1->add_control(
			'image',
			[
				'label' 		=> __( 'Image', 'metize' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' 			=> Utils::get_placeholder_image_src(),
				],
				'condition'		=> [ 'img_or_icon' => [ '2']  ],
			]
		);
		$repeater1->add_control(
			'btn_txt',
			[
				'label'     	=> __( 'Button Text', 'metize' ),
                'type'      	=> Controls_Manager::TEXTAREA,
                'rows' 			=> 2,
                'default' 		=>  __( 'All Services', 'metize'),
			]
        );
        $repeater1->add_control(
			'btn_url',
			[
				'label'     	=> __( 'Button url', 'metize' ),
                'type'      	=> Controls_Manager::TEXTAREA,
                'rows' 			=> 2,
                'default' 		=>  __( '#', 'metize'),
			]
        );
        
        $this->add_control(
			'process',
			[
				'label' 		=> __( 'Process', 'metize' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater1->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'title', 'metize' ),
					],
				],
				'title_field' 	=> '{{{ process_title }}}',
			]
		);
		$this->add_control(
			'counterup',
			[
				'label'     => __( 'Counter up', 'metize' ),
                'type'      => Controls_Manager::WYSIWYG,
                'rows' 		=> 2,
                'default' 		=> __( '' , 'metize' ),
                'condition'		=> [ 'layout' => [ '4']  ],
			]
        );

        $repeater2 = new Repeater();

		
		$repeater2->add_control(
			'progressbar_title',
			[
				'label'     => __( 'Progressbar Title', 'metize' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default' 		=> __( 'Business Idea' , 'metize' ),
			]
        );
        $repeater2->add_control(
			'progressbar_shuffix',
			[
				'label'     => __( 'Progressbar Shuffix', 'metize' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default' 		=> __( 'K' , 'metize' ),
			]
        );
        
        $repeater2->add_control(
			'progressbar_number',
			[
				'label'     => __( 'Progressbar Number', 'metize' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default' 		=> __( '88' , 'metize' ),
			]
        );
        

        $this->add_control(
			'values',
			[
				'label' 		=> __( 'items', 'metize' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater2->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'title', 'metize' ),
					],
				],
				'title_field' 	=> '{{{ progressbar_title }}}',
				'condition'		=> [ 'layout' => ['5']  ],
			]
		);

        $this->end_controls_section();


        $this->start_controls_section(
			'Section_header_styling',
			[
				'label' 	=> __( 'Header Style', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'		=> [ 'layout' => ['1','3']  ],
			]
        );
        $this->start_controls_tabs(
			'header_tabs1'
		);

		//--------------------first tab start--------------------//

		$this->start_controls_tab(
			'header_title',
			[
				'label' => esc_html__( 'Title', 'metize' ),
			]
		);
        $this->add_control(
			'header_from_color',
			[
				'label' 		=> __( 'Gradient Color From', 'digalu' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .sub-title' => '--color-primary: {{VALUE}}!important;',
                ],
			]
        );
        $this->add_control(
			'header_to_color',
			[
				'label' 		=> __( 'Gradient Color To', 'digalu' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .sub-title' => '--color-secondary: {{VALUE}}!important;',
                ],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 'header_title_typography',
		 		'label' 		=> __( 'Typography', 'metize' ),
		 		'selector' 	=> '{{WRAPPER}} .sub-title',
			]
		);

        $this->add_responsive_control(
			'header_title_margin',
			[
				'label' 		=> __( 'Margin', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'header_title_padding',
			[
				'label' 		=> __( 'Padding', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

		$this->end_controls_tab();

		//--------------------first tab end--------------------//


		//--------------------2nd tab start--------------------//

		$this->start_controls_tab(
			'header_tabs2',
			[
				'label' => esc_html__( 'subtitle', 'metize' ),
			]
		);
		$this->add_control(
			'header_subtitle_color',
			[
				'label' 		=> __( 'Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} h2'	=> '--color-heading: {{VALUE}}!important;',
				],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 'header_subtitle_typography',
		 		'label' 		=> __( 'Typography', 'metize' ),
		 		'selector' 	=> '{{WRAPPER}} h2',
			]
		);

        $this->add_responsive_control(
			'header_subtitle_margin',
			[
				'label' 		=> __( 'Margin', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'header_subtitle_padding',
			[
				'label' 		=> __( 'Padding', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );



		$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();

        
        //---------------------------------------Title Style---------------------------------------//

		$this->start_controls_section(
			'title_style',
			[
				'label' 	=> __( 'Title Style', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' 		=> __( 'Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .cont h4' => 'color: {{VALUE}}',
					'{{WRAPPER}} .cont h3' => 'color: {{VALUE}}',
                ],
			]
        );
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> __( 'Typography', 'metize' ),
                'selector' 	=> '{{WRAPPER}} .cont h4, {{WRAPPER}} .cont h3',
			]
        );
        $this->add_responsive_control(
			'title_margin',
			[
				'label' 		=> __( 'Margin', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h4, {{WRAPPER}} .cont h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'title_padding',
			[
				'label' 		=> __( 'Padding', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h4, {{WRAPPER}} .cont h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);
		$this->end_controls_section();

		//---------------------------------------Content Style---------------------------------------//

		$this->start_controls_section(
			'content_style',
			[
				'label' 	=> __( 'Content Style', 'metize' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' 		=> __( 'Color', 'metize' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .cont p' => 'color: {{VALUE}}',
                ],
			]
        );
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'content_typography',
				'label' 	=> __( 'Typography', 'metize' ),
                'selector' 	=> '{{WRAPPER}} .cont p',
			]
        );
        $this->add_responsive_control(
			'content_margin',
			[
				'label' 		=> __( 'Margin', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .cont p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'content_padding',
			[
				'label' 		=> __( 'Padding', 'metize' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .cont p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);
		$this->end_controls_section();
	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        if($settings['layout'] == 1) {

        	$shape = $settings['bg']['url'] ? $settings['bg']['url'] : '#';
			echo '<div class="feature-style-one-area default-padding">';
		        echo '<div class="shape">';
		            echo '<img src="'.esc_url( $shape ).'" alt="Image Not Found">';
		        echo '</div>';
		        echo '<div class="container">';
		            echo '<div class="row">';
		                echo '<div class="col-lg-4">';
		                	if( ! empty( $settings['title'] ) ){
		                        echo '<h4 class="sub-title">'.esc_html( $settings['title'] ).'</h4>';
		                    }
		                    if( ! empty( $settings['subtitle'] ) ){
		                        echo '<h2 class="title mb-30 mb-md-50">'.wp_kses_post( $settings['subtitle'] ).'</h2>';
		                    }
		                    if( ! empty( $settings['desc'] ) ){
			                    echo '<div class="feature-alert">';
			                    	echo wp_kses_post( $settings['desc'] );
			                    echo '</div>';
			                }
		                echo '</div>';
		                echo '<div class="col-lg-7 offset-lg-1">';
		                    echo '<div class="row cont">';
		                       
		                    	foreach( $settings['process'] as $single_data ) { 
			                        echo '<div class="col-md-6 mb-30">';
			                            echo '<div class="feature-style-one-item animate" data-animate="fadeInUp">';

			                            	if($single_data['img_or_icon'] == 1) {
			                            	
				                                if(!empty($single_data['icon'])){
									                echo wp_kses_post($single_data['icon']);
									            }
									        }else{
									        	if( ! empty( $single_data['image']['url'] ) ){
							                        echo '<div class="icon">';
							                            echo metize_img_tag( array(
															'url'	=> esc_url( $single_data['image']['url'] )
														) );
							                        echo '</div>';
							                    }
									        }
			                                if(!empty($single_data['process_title'])){
								                echo '<h4>'.esc_html($single_data['process_title']).'</h4>';
								            }
				                            if(!empty($single_data['process_con'])){
								                echo '<p>'.esc_html($single_data['process_con']).'</p>';
								            }
			                            echo '</div>';
			                        echo '</div>';
			                    }
		                    echo '</div>';
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}elseif($settings['layout'] == 2 ) {
			echo '<div class="feature-style-two-area default-padding-bottom">';
		        echo '<div class="container">';
		            echo '<div class="feature-two-box mt--50 mt-xs-0">';
		                echo '<div class="row">';
		                	$i = 0;
		                	foreach( $settings['process'] as $single_data ) { 
		                		$i++;
    							$k = str_pad($i, 2, '0', STR_PAD_LEFT);

			                    echo '<!-- Single Item -->';
			                    echo '<div class="col-lg-4 col-md-6">';
			                        echo '<div class="feature-style-two cont">';
			                            echo '<span>'.esc_attr( $k ).'</span>';
			                           	if($single_data['img_or_icon'] == 1) {
			                            	
			                                if(!empty($single_data['icon'])){
								                echo wp_kses_post($single_data['icon']);
								            }
								        }else{
								        	if( ! empty( $single_data['image']['url'] ) ){
						                        echo '<div class="icon">';
						                            echo metize_img_tag( array(
														'url'	=> esc_url( $single_data['image']['url'] )
													) );
						                        echo '</div>';
						                    }
								        }
			                            if(!empty($single_data['process_title'])){
							                echo '<h3>'.esc_html($single_data['process_title']).'</h3>';
							            }
			                            if(!empty($single_data['process_con'])){
							                echo '<p>'.esc_html($single_data['process_con']).'</p>';
							            }
			                        echo '</div>';
			                    echo '</div>';
			                }
		                    
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}elseif($settings['layout'] == 3 ) {
			$shape = $settings['bg']['url'] ? $settings['bg']['url'] : '#';
			echo '<div class="feature-style-four-area">';
		        echo '<div class="container">';
		            echo '<div class="row">';
		                echo '<div class="col-lg-8 offset-lg-2">';
		                    echo '<div class="site-heading text-center ">';
		                    	if( ! empty( $settings['title'] ) ){
			                        echo '<h4 class="sub-title">'.esc_html( $settings['title'] ).'</h4>';
			                    }
			                    if( ! empty( $settings['subtitle'] ) ){
			                        echo '<h2 class="title">'.wp_kses_post( $settings['subtitle'] ).'</h2>';
			                    }
		                    echo '</div>';
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		        echo '<div class="container">';
		            echo '<div class="feature-four-items bg-cover text-light" style="background-image: url('.esc_url( $shape ).');">';
		                echo '<div class="row">';
		                    foreach( $settings['process'] as $single_data ) { 
			                    echo '<!-- Single Item -->';
			                    echo '<div class="col-lg-4">';
			                        echo '<div class="feature-style-four cont">';
			                            if($single_data['img_or_icon'] == 1) {
			                            	
			                                if(!empty($single_data['icon'])){
								                echo wp_kses_post($single_data['icon']);
								            }
								        }else{
								        	if( ! empty( $single_data['image']['url'] ) ){
					                            echo metize_img_tag( array(
													'url'	=> esc_url( $single_data['image']['url'] )
												) );
						                    }
								        }
			                            if(!empty($single_data['process_title'])){
							                echo '<h3>'.esc_html($single_data['process_title']).'</h3>';
							            }
							            if( ! empty( $single_data['btn_txt'] ) ){
				                            echo '<a href="'.esc_url( $single_data['btn_url'] ).'">'.esc_html( $single_data['btn_txt'] ).' <i class="fas fa-arrow-right"></i></a>';
				                        }
			                        echo '</div>';
			                    echo '</div>';
			                    echo '<!-- End Single Item -->';
			                }
		                    
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		   echo '</div>';
		}elseif($settings['layout'] == 4 ) {
			$shape = $settings['bg']['url'] ? $settings['bg']['url'] : '#';
			echo '<div class="feature-style-five-area default-padding" style="background-image: url('.esc_url( $shape ).');">';
		        echo '<div class="container">';
		            echo '<div class="feature-style-five-items">';
		                echo '<div class="row align-center">';
		                    echo '<div class="col-xl-8">';
		                        echo '<div class="row">';
		                            foreach( $settings['process'] as $single_data ) { 
			                            echo '<!-- Single Item -->';
			                            echo '<div class="col-lg-6 col-md-6 item">';
			                                echo '<div class="feature-style-five animate" data-animate="fadeInUp">';
			                                    if($single_data['img_or_icon'] == 1) {
			                            	
					                                if(!empty($single_data['icon'])){
										                echo wp_kses_post($single_data['icon']);
										            }
										        }else{
										        	if( ! empty( $single_data['image']['url'] ) ){
								                        echo '<div class="icon">';
								                            echo metize_img_tag( array(
																'url'	=> esc_url( $single_data['image']['url'] )
															) );
								                        echo '</div>';
								                    }
										        }
			                                    echo '<div class="info">';
			                                        if(!empty($single_data['process_title'])){
										                echo '<h4>'.esc_html($single_data['process_title']).'</h4>';
										            }
						                            if(!empty($single_data['process_con'])){
										                echo '<p>'.esc_html($single_data['process_con']).'</p>';
										            }
			                                    echo '</div>';
			                                echo '</div>';
			                            echo '</div>';
			                            echo '<!-- End Single Item -->';
			                        }
		                            

		                        echo '</div>';
		                    echo '</div>';
		                    echo '<div class="col-xl-3 offset-xl-1">';
		                    if( ! empty( $settings['counterup'] ) ){
			                    echo wp_kses_post( $settings['counterup'] );
			                }  
		                    echo '</div>';
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}else{
			echo '<div class="feature-style-three-area">';
		        echo '<div class="container">';
		            echo '<div class="row align-center">';
		                echo '<!-- Single Item -->';
		                echo '<div class="col-lg-4 mb-30">';
		                    echo '<ul class="feature-fun-fact">';

		                    	foreach( $settings['values'] as $single_data ) { 
			                        echo '<li>';
			                            echo '<div class="fun-fact">';
			                                echo '<div class="counter">';
			                                	if( ! empty( $single_data['progressbar_number'] ) ){
				                                    echo '<div class="timer" data-to="'.esc_attr( $single_data['progressbar_number'] ).'" data-speed="4000">'.esc_html( $single_data['progressbar_number'] ).'</div>';
				                                }
			                                    if( ! empty( $single_data['progressbar_shuffix'] ) ){
				                                    echo '<div class="operator">'.esc_html( $single_data['progressbar_shuffix'] ).'</div>';
				                                }

			                                echo '</div>';
			                                if( ! empty( $single_data['progressbar_title'] ) ){
				                                echo '<span class="medium">'.esc_html( $single_data['progressbar_title'] ).'</span>';
				                            }
			                            echo '</div>';
			                        echo '</li>';
			                    }
		                        
		                    echo '</ul>';
		                echo '</div>';
		                echo '<!-- End Single Item -->';

		                foreach( $settings['process'] as $single_data ) { 
			                echo '<!-- Single Item -->';
			                echo '<div class="col-lg-4 col-md-6 mb-30">';
			                    echo '<div class="feature-style-three cont animate" data-animate="fadeInUp">';
			                        echo '<div class="info">';
			                            if(!empty($single_data['process_title'])){
							                echo '<h4>'.esc_html($single_data['process_title']).'</h4>';
							            }
							            if(!empty($single_data['process_con'])){
							                echo '<p>'.wp_kses_post($single_data['process_con']).'</p>';
							            }
			                        echo '</div>';
			                        if($single_data['img_or_icon'] == 1) {
			                            	
		                                if(!empty($single_data['icon'])){
							                echo wp_kses_post($single_data['icon']);
							            }
							        }else{
							        	if( ! empty( $single_data['image']['url'] ) ){
					                        echo '<div class="icon">';
					                            echo metize_img_tag( array(
													'url'	=> esc_url( $single_data['image']['url'] )
												) );
					                        echo '</div>';
					                    }
							        }
			                    echo '</div>';
			                echo '</div>';
			                echo '<!-- End Single Item -->';
		            	}
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}
	}
}